<!DOCTYPE html>


<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Document</title>


    <link rel="stylesheet" href="dist/css/bulma.css">
    <link rel="stylesheet" href="dist/css/main.css">
</head>

<body>



    <section class="section fadein_slowly" id="section" style="margin:auto 0;">
        <div class="container">

            <h1 style="font-size:50px;">
                <span id="metamusic">Meta</span> Music</h1>



            <br> {% block content %} {% endblock content %}




        </div>
    </section>
    {% block button %} {% endblock button %} {% block script %} {% endblock script %}
</body>

</html>