{% extends "layout.html" %} {% block content %}
<center>
    <img src="dist/img/error.png" alt="error">
</center>

<h1 style="font-size:25px;color:black;">

    File was not Found. Please enter a proper File/ File Directory Path
</h1>
{% endblock content %}