h1 {
  margin-bottom: 20px;
  font-size: 20px;
  font-weight: 300;
  text-align: center;
  text-transform: uppercase;
  letter-spacing: 5px;
  color: #bbb;
}
h1 #metamusic {
  border: 2px solid #26a69a;
  padding: 3px 2px 3px 7px;
  border-radius: 6px;
  font-weight: 400;
}

input {
  text-align: center;
}
input[type="submit"] {
  display: block;
  margin: 0 auto;
}
.inblock {
  display: :inline-block;
}
body,
html {
  background-color: #eee;
  font-family: "Open Sans", sans-serif;
  font-size: 16px;
  font-weight: 400;
  color: #000;
}

.skill-card {
  display: block;
  padding: 20px;
  width: 20em;
  margin:8px;
  background-color: #fff;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12),
    0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  cursor: pointer;
}
.skill-card:hover {
  -webkit-box-shadow: 0 14px 28px rgba(0, 0, 0, 0.25),
    0 10px 10px rgba(0, 0, 0, 0.22);
  box-shadow: 0 14px 28px rgba(0, 0, 0, 0.25), 0 10px 10px rgba(0, 0, 0, 0.22);
}
.skill-card:hover .skill-card__header {
  height: 40px;
}
.skill-card:hover .skill-card__header .skill-card__icon {
  -webkit-transform: translateX(-50%) translateY(-50%) scale(3);
  transform: translateX(-50%) translateY(-50%) scale(3);
}
.skill-card:hover .skill-card__body {
  height: 170px;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li {
  -webkit-transform: translateX(0);
  transform: translateX(0);
  -webkit-transition-timing-function: cubic-bezier(0, 1.5, 1, 1);
  transition-timing-function: cubic-bezier(0, 1.5, 1, 1);
  -webkit-transition-duration: 0.5s;
  transition-duration: 0.5s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(1) {
  -webkit-transition-delay: 0.25s;
  transition-delay: 0.25s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(2) {
  -webkit-transition-delay: 0.5s;
  transition-delay: 0.5s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(3) {
  -webkit-transition-delay: 0.75s;
  transition-delay: 0.75s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(4) {
  -webkit-transition-delay: 1s;
  transition-delay: 1s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(5) {
  -webkit-transition-delay: 1.25s;
  transition-delay: 1.25s;
}
.skill-card:hover .skill-card__body .skill-card__knowledge li:nth-child(6) {
  -webkit-transition-delay: 1.5s;
  transition-delay: 1.5s;
}
.skill-card .skill-card__header {
  position: relative;
  background-color: #eb6c3f;
  height: 170px;
  margin: -20px -20px 20px -20px;
  -webkit-transition: height 0.5s;
  transition: height 0.5s;
  overflow: hidden;
}
.skill-card .skill-card__header .skill-card__icon {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translateY(-50%) translateX(-50%);
  transform: translateY(-50%) translateX(-50%);
  display: block;
  width: 128px;
  height: 128px;
  -webkit-transition: -webkit-transform 0.5s;
  transition: -webkit-transform 0.5s;
  transition: transform 0.5s;
  transition: transform 0.5s, -webkit-transform 0.5s;
}
.skill-card .skill-card__body {
  height: 50px;
  -webkit-transition: height 0.5s;
  transition: height 0.5s;
  overflow: hidden;
}
.skill-card .skill-card__body .skill-card__title {
  font-size: 1.4em;
  font-weight: 600;
  text-transform: uppercase;
}
.skill-card .skill-card__body .skill-card__duration {
  color: #9e9e9e;
  font-style: italic;
}
.skill-card .skill-card__body .skill-card__knowledge {
  margin-top: 10px;
  color: #424242;
}
.skill-card .skill-card__body .skill-card__knowledge li {
  margin-top: 5px;
  -webkit-transition-duration: 0;
  transition-duration: 0;
  -webkit-transition-delay: 0.5s;
  transition-delay: 0.5s;
  -webkit-transform: translateX(-100%);
  transform: translateX(-100%);
}



#vis {
  position: fixed;
  top: 0%;
  left: 0%;
  width: 100%;
  height: 100%;
  background: #00d1b2;
  border-radius: 0px;

  transition: visibility 0s 3s, opacity 3s ;
}




.fadeout_slowly {
  
  animation: fadeout 3s;
  -moz-animation: fadeout 3s; /* Firefox */
  -webkit-animation: fadeout 3s; /* Safari and Chrome */
  -o-animation: fadeout 3s; /* Opera */
}
@keyframes fadeout {
  from {
      opacity:1;
  }
  to {
      opacity:0;
  }
}
@-moz-keyframes fadeout { /* Firefox */
  from {
      opacity:1;
  }
  to {
      opacity:0;
  }
}
@-webkit-keyframes fadeout { /* Safari and Chrome */
  from {
      opacity:1;
  }
  to {
      opacity:0;
  }
}
@-o-keyframes fadeout { /* Opera */
  from {
      opacity:1;
  }
  to {
      opacity:0;
  }
}

















.fadein_slowly {
  
  animation: fadein 2s;
  -moz-animation: fadein 1s; /* Firefox */
  -webkit-animation: fadein 1s; /* Safari and Chrome */
  -o-animation: fadein 1s; /* Opera */
}
@keyframes fadein {
  from {
      opacity:0;
  }
  to {
      opacity:1;
  }
}
@-moz-keyframes fadein { /* Firefox */
  from {
      opacity:0;
  }
  to {
      opacity:1;
  }
}
@-webkit-keyframes fadein { /* Safari and Chrome */
  from {
      opacity:0;
  }
  to {
      opacity:1;
  }
}
@-o-keyframes fadein { /* Opera */
  from {
      opacity:0;
  }
  to {
      opacity: 1;
  }
}