html {
  height: 100%;
}

body {
  height: 100%;
}

h1 {
  margin-bottom: 20px;
  font-size: 20px;
  font-weight: 300;
  text-align: center;
  text-transform: uppercase;
  letter-spacing: 5px;
  color: #bbb;
}
h1 #metamusic {
  border: 2px solid #26a69a;
  padding: 3px 2px 3px 7px;
  border-radius: 15px;
  font-weight: 400;
}

input {
  text-align: center;
}
input[type="submit"] {
  display: block;
  margin: 0 auto;
}

#vis {
  visibility: hidden;
  position: fixed;
  top: 65%;
  left: 45%;
  width: 135px;
  height: 55px;
  background: #00d1b2;
  border-radius: 40px;

  transition: all 0.4s;
  -moz-transition: 0.4s;
}

.inblock {
  display: inline-block;
}
.inputHeight {
  height: 60px;
}
#section {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translateX(-50%) translateY(-50%);
}

.fadein_slowly {
  animation: fadein 1s;
  -moz-animation: fadein 1s; /* Firefox */
  -webkit-animation: fadein 1s; /* Safari and Chrome */
  -o-animation: fadein 1s; /* Opera */
}
@keyframes fadein {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@-moz-keyframes fadein {
  /* Firefox */
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@-webkit-keyframes fadein {
  /* Safari and Chrome */
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@-o-keyframes fadein {
  /* Opera */
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
